aboutsummaryrefslogtreecommitdiffstats
path: root/src/arena.c
diff options
context:
space:
mode:
authorJason Evans <jasone@canonware.com>2017-04-26 16:26:12 -0700
committerJason Evans <jasone@canonware.com>2017-04-29 09:24:12 -0700
commitb9ab04a191dbcb9246d5180fc7ae822a85861939 (patch)
treeea4a2c8b8fd64b79499ad4680a2989e99e030464 /src/arena.c
parentd901a377753cf4c75d2f72f7a692c44f61eac4a4 (diff)
downloadplatform_external_jemalloc_new-b9ab04a191dbcb9246d5180fc7ae822a85861939.tar.gz
platform_external_jemalloc_new-b9ab04a191dbcb9246d5180fc7ae822a85861939.tar.bz2
platform_external_jemalloc_new-b9ab04a191dbcb9246d5180fc7ae822a85861939.zip
Refactor !opt.munmap to opt.retain.
Diffstat (limited to 'src/arena.c')
-rw-r--r--src/arena.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/arena.c b/src/arena.c
index 3b94a20d..2c7cea08 100644
--- a/src/arena.c
+++ b/src/arena.c
@@ -1143,8 +1143,8 @@ arena_destroy_retained(tsdn_t *tsdn, arena_t *arena) {
* opportunity to unmap all retained memory without having to keep its
* own metadata structures, but if deallocation fails, that is the
* application's decision/problem. In practice, retained extents are
* leaked here if !opt_munmap unless the application provided custom
* extent hooks, so best practice is to either enable munmap (and avoid
* dss for arenas to be destroyed), or provide custom extent hooks that
* either unmap retained extents or track them for later use.
*/
@@ -1947,7 +1947,7 @@ arena_new(tsdn_t *tsdn, unsigned ind, extent_hooks_t *extent_hooks) {
goto label_error;
}
- if (!opt_munmap) {
+ if (opt_retain) {
atomic_store_u(&arena->extent_grow_next, psz2ind(HUGEPAGE),
ATOMIC_RELAXED);
}
@@ -1143,8 +1143,8 @@ arena_destroy_retained(tsdn_t *tsdn, arena_t *arena) {
* own metadata structures, but if deallocation fails, that is the
* application's decision/problem. In practice, retained extents are
- * leaked here if !opt_munmap unless the application provided custom
- * extent hooks, so best practice is to either enable munmap (and avoid
+ * leaked here if opt_retain unless the application provided custom
+ * extent hooks, so best practice is to either disable retain (and avoid
* dss for arenas to be destroyed), or provide custom extent hooks that
* either unmap retained extents or track them for later use.